<?php

/**
 * @file
 * The core customizations for Hiya theme.
 */

/**
 * Implements hook_preprocess_node().
 */
function hiya_preprocess_node(&$variables) {
  if ($variables['type'] == 'article' || $variables['type'] == 'blog') {
    $node = $variables['node'];
    $variables['submitted_day'] = format_date($node->created, 'custom', 'j');
    $variables['submitted_month'] = format_date($node->created, 'custom', 'M');
    $variables['submitted_year'] = format_date($node->created, 'custom', 'Y');
  }
}

/**
 * Implements hook_preprocess_page().
 */
function hiya_preprocess_page(&$variables) {
  $element = array(
    '#tag' => 'link',
    '#attributes' => array(
      'href' => 'http://fonts.googleapis.com/css?family=Ubuntu|Crete+Round|Doppio+One',
      'rel' => 'stylesheet',
      'type' => 'text/css',
    ),
  );
  drupal_add_html_head($element, 'google_font_hiya');
  if ($variables['page']['sidebar']) {
    $variables['sidebar_grid'] = 'grid_9';
  }
  else {
    $variables['sidebar_grid'] = 'grid_12';
  }
}

/**
 * Implements hook_preprocess_comment_wrapper().
 */
function hiya_preprocess_comment_wrapper(&$vars) {
  $node = $vars['node'];
  $vars['counter'] = format_plural($node->comment_count, '1 comment', '@count comments');
}

/**
 * Implements hook_preprocess_comment().
 */
function hiya_preprocess_comment(&$vars) {
  $node = $vars['node'];
  $comment = $vars['elements']['#comment'];
  $uri = entity_uri('comment', $comment);
  $day = format_date($node->created, 'custom', 'j');
  $month = format_date($node->created, 'custom', 'F');
  $year = format_date($node->created, 'custom', 'Y');
  $vars['permalink'] = l(t('!datetime', array('!datetime' => $month . ' ' . $day . ', ' . $year)), $uri['path'], $uri['options']);
}

/**
 * Implements hook_form_FORM_ID_alter().
 */
function hiya_form_comment_node_article_form_alter(&$form, &$form_state) {
  $form['author']['welcome']['#value'] = "Share your thoughts " . $form['author']['name']['#value'];
  $form['author']['_author'] = '';
}

/**
 * Implements hook_form_FORM_ID_alter().
 */
function hiya_form_comment_node_blog_form_alter(&$form, &$form_state) {
  $form['author']['welcome']['#value'] = "Share your thoughts " . $form['author']['name']['#value'];
  $form['author']['_author'] = '';
}

/**
 * Implements hook_form_FORM_ID_alter().
 */
function hiya_form_search_block_form_alter(&$form, &$form_state) {
  $form['search_block_form']['#size'] = "17";
  $form['search_block_form']['#default_value'] = "Search...";
  $form['actions']['submit']['#attributes']['id'] = "search-form-button";
  $form['search_block_form']['#attributes']['class'][] = "search-box";
}

/**
 * Implements hook_form_FORM_ID_alter().
 */
function hiya_form_search_form_alter(&$form, &$form_state, $form_id) {
  $form['basic']['submit']['#attributes']['id'] = "search-form-button";
  $form['basic']['keys']['#attributes']['class'][] = "search-box";
}
