<?php
/**
 * @file
 * Default theme implementation to display a single Drupal page.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/bartik.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 *
 * Navigation:
 * - $main_menu (array): An array containing the Main menu links for the
 *   site, if they have been configured.
 * - $secondary_menu (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 * - $breadcrumb: The breadcrumb trail for the current page.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *   (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *   menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *   associated with the page, and the node ID is the second argument
 *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *   comment/reply/12345).
 *
 * Regions:
 * - $page['featured']: Items for the featured content region.
 * - $page['content']: The main content of the current page.
 * - $page['sidebar']: Items for the first sidebar.
 * - $page['header']: Items for the header region.
 * - $page['footer_one']: Items for the footer region.
 * - $page['footer_two']: Items for the footer region.
 * - $page['footer_three']: Items for the footer region.
 * - $page['footer_last']: Items for the footer region.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 * @see template_process()
 */
?>

<div id="wrapper" class="container_12">
  <div id="header" class="grid_12 alpha omega">
    <div id="logo" class="grid_3 alpha">
      <?php if ($logo): ?>
        <a href="<?php print check_url($front_page); ?>" title="<?php print t('Home'); ?>">
          <img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>" />
        </a>
      <?php endif; ?>
    </div>
    <?php if ($site_name || $site_slogan): ?>

      <?php if ($site_name): ?>
        <h1 class="title grid_6">
          <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home"><span><?php print $site_name; ?></span></a>
        </h1>
      <?php endif; ?>

      <?php if ($site_slogan): ?>
        <h2 class="tagline grid_6"><?php print $site_slogan; ?></h2>
      <?php endif; ?>
      <!-- /#name-and-slogan -->
    <?php endif; ?>
    <div id="nav" class="grid_6">
      <?php if ($main_menu): ?>
        <?php
        $menu_name = variable_get('menu_main_links_source', 'main-menu');
        $main_menu_tree = menu_tree($menu_name);
        print drupal_render($main_menu_tree);
        ?>
      <?php endif; ?>
    </div>
    <?php if ($page['header']): ?>
      <div class="head grid_3 omega">
        <?php print render($page['header']); ?>
      </div>
    <?php endif; ?>
  </div>
  <div class="clear"></div>
  <div id="content_area" class="grid_12 alpha omega">
    <?php if ($page['featured']): ?>
      <div class="featured clearfix">
        <?php print render($page['featured']); ?>
      </div><!-- /.featured -->
    <?php endif; ?>
    <div class="rectangle"></div>
    <div class="triangle-l"></div>
    <div class="triangle-r"></div>
    <div class="post <?php print $sidebar_grid; ?> alpha">
      <?php print render($title_prefix); ?>
      <?php if ($title): ?><h2 class="page_title"><?php print $title; ?></h2><?php endif; ?>
      <div class="postinfo"><?php print render($title_suffix); ?></div>
      <?php if ($tabs): ?><div class="tabs"><?php print render($tabs); ?></div><?php endif; ?>
      <?php print $messages; ?>
      <?php if ($action_links): ?><ul class="action-links"><?php print render($action_links); ?></ul><?php endif; ?>
      <?php print render($page['content']);
      ?>
      <?php print $feed_icons; ?>
    </div>

    <?php
    /*
     * rendering the sidebar region
     */
    ?>
    <?php if ($page['sidebar']): ?>
      <div class="sidebar grid_3 omega">
        <?php print render($page['sidebar']); ?>
      </div>
    <?php endif; ?>
  </div>
  <?php
  /*
   * rendering the footer region
   */
  ?>
  <?php if ($page['footer_one'] || $page['footer_two'] || $page['footer_three']): ?>
    <div class="footer grid_12 alpha omega">
      <?php if ($page['footer_one']): ?>
        <div class="footer_col grid_4 alpha">
          <?php print render($page['footer_one']); ?>
        </div>
      <?php endif; ?>
      <?php if ($page['footer_two']): ?>
        <div class="footer_col grid_4">
          <?php print render($page['footer_two']); ?>
        </div>
      <?php endif; ?>
      <?php if ($page['footer_three']): ?>
        <div class="footer_col grid_4 omega">
          <?php print render($page['footer_three']); ?>
        </div>
      <?php endif; ?>
    <?php endif; ?>
    <?php if ($page['footer_last']): ?>
      <div class="footer_last grid_12 alpha omega">
        <?php print render($page['footer_last']); ?>
      </div>
    <?php endif; ?>
  </div>

</div><!-- /#page, /#page-wrapper -->
